require 'spec_helper'

module Quby::Compiler::Entities
  describe ScoreSchema do
    let(:suboptions) { {key: :value, export_key: :tot, label: 'Somscore'} }
    let(:schema_options) { {key: :totaal, label: 'Totaalscore', subscore_schemas: [suboptions]} }
    subject { ScoreSchema.new schema_options }

    describe '#export_key_labels' do
      it 'returns the score label associated with the given short key' do
        expect(subject.export_key_labels[:tot]).to eq('Somscore')
      end

      it 'searches with indifferent access' do
        expect(subject.export_key_labels['tot']).to eq('Somscore')
      end

      it 'returns nil if the score can not be found' do
        expect(subject.export_key_labels[:wah]).to eq(nil)
      end
    end

    describe 'when the scoreschema is invalid' do
      let(:schema_options) { {key: :value} }

      it 'sets helpful error messages' do
        expect{subject}.to raise_error '[Quby::Compiler::Entities::ScoreSchema.new] :label is missing in Hash input'
      end
    end

    describe 'when the subscoreschema is invalid' do
      let(:suboptions) { {key: :value} }
      it 'raises' do
        expect{subject}.to raise_error '[Quby::Compiler::Entities::SubscoreSchema.new] :label is missing in Hash input'
      end
    end
  end
end
